@@ -792,7 +792,7 @@ class DeliveryOrderClient(EntityClientBase):
     def change_planning(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-planning".format(id), params)
 
-    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", file_name=None, lob=1):
+    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", file_name=None, lob=1, target_name=None):
         params = {
             'user_name': user_name,
             'sender_code': sender_code,
@@ -801,6 +801,8 @@ class DeliveryOrderClient(EntityClientBase):
             'file_name': file_name,
             'lob': lob
         }
+        if target_name is not None:
+            params.update({'target_name': target_name})
         return self.http_post_json(self.entity_endpoint_base_url + "_upload-file", params)
 
     def validate_customer(self, id, params):
@@ -827,6 +829,9 @@ class DeliveryOrderClient(EntityClientBase):
     def change_b2c_delivery(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-b2c-delivery".format(id), params)
 
+    def change_b2b_delivery(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-b2b-delivery".format(id), params)
+
     def masive_change_b2c_delivery(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_masive_change-b2c-delivery", params)
 
@@ -892,6 +897,12 @@ class DeliveryOrderClient(EntityClientBase):
     def slack_report_send(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_slack-report-send", params)
 
+    def set_packed_items(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_set-packed_items", params)
+
+    def set_packed_items(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_set-packed_items".format(id), params)
+
     def physically_receive(self, id, event_info, pasync=True):
         if pasync:
             return TaskClient(**self.args).enqueue('delivery-order-physically-receive', {
