@@ -20,3 +20,6 @@ class BulkClient(EntityClientBase):
 
     def ser_travelling_receive(self, code):
         return self.http_post_json(self.entity_endpoint_base_url + "_ser-travelling-receive", code)
+    
+    def cd_travelling_receive(self, id, event_info):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_cd-travelling-receive".format(id), event_info)
